Crate scsys_traits

A collection of useful traits designed to be used throughout the ecosystem.

Modules

adjust
container
convert
dtype
hkt
named
store
string
symbolic
toggle
wrapper

Traits

Adjust
Appellation
AsSlice
AsSliceMut
Context
DType
DType is a trait designed to provide additional information regarding the type of a particular value.
Decrement
Decrement is a trait describing the ability to decrement a value.
Displayable
Displayable simply combines the two major traits core::fmt::Debug and core::fmt::Display into a single trait. This is useful for types that need to be displayed in a human-readable format, such as in debugging or logging.
Entry
Functor
HKT
Increment
IntoInner
IntoInner is typically used for basic structures that wrap a single value.
IsType
Mapper
Named
Interface for nameable data-structures
OrInsert
RawContainer
RawContainer defines a standard interface for all containers that are used to store other entities.
RawWrapper
A RawWrapper is the base trait defining all so-called “wrapper” types.
RemoveFnl
This trait defines a method for removing the first and last entries within an entity.
Store
StringFmt
Symbolic
Symbolic denotes a type consisting of some single or set of value(s) that can are considered displayable. Essentially, this trait is a wrapper around the Displayable trait enabling additional implementations
TypeOf
TypeTag
Typically, TypeTag is used for uninitaliziable enums with no variants
Wrapper
The Wrapper trait is used to establish a common interface for all simplemented structures that “wrap” a single value. Essentially, any type capable of implementing #[repr(transparent)] can be considered a wrapper.
WrapperExt
WrapperExt is an automatically implemented trait extending the Wrapper trait with additional